<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CheckForUpdates</name>
    <message>
        <location filename="../CheckForUpdates.js" line="+62"/>
        <location filename="../CheckForUpdatesDialog.ui" line="+14"/>
        <source>Checking for Updates...</source>
        <translation>アップデートを確認しています...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Version information not found.</source>
        <translation>バージョン情報が見つかりません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>No connection to server or file not found. Please try again later.</source>
        <translation>サーバへの接続が無いか、ファイルが見つかりません。後ほど、再度お試し下さい。</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location filename="../CheckForUpdatesDialog.ui" line="+53"/>
        <source>Automatically check for updates</source>
        <translation>アップデートの確認を自動的に行う</translation>
    </message>
    <message>
        <location filename="../CheckForUpdatesInit.js" line="+6"/>
        <source>Check for &amp;Updates...</source>
        <translation>&amp;U アップデート確認...</translation>
    </message>
</context>
</TS>
